export const clientLookup = new Map();
/**
 * Class representing a client that has connected to the dev server
 */
export default class ClientConnection {
    constructor(url, target) {
        this.activePaths = new Map();
        this.url = url;
        this.target = target;
        clientLookup.set(ClientConnection.getKey(this.url, this.target), this);
    }
    static getKey(url, target) {
        return `${url}:${target}`;
    }
    addActivePaths(paths) {
        paths.forEach(({ modulePath, compileOptions }) => {
            const existing = this.activePaths.get(modulePath);
            if (!existing) {
                this.activePaths.set(modulePath, compileOptions);
            }
        });
    }
    removeStalePaths(paths) {
        paths.forEach((p) => this.activePaths.delete(p));
    }
    getCompileOptions(path) {
        return this.activePaths.get(path);
    }
}
//# sourceMappingURL=clientConnection.js.map