import { LogLevel } from '../../types/index.js';
import { getWorkspaceScanner } from './workspaceScanner/index.js';
export class ModuleGraph {
    constructor(workspace, paths, logger) {
        /**
         * All modules paths that are being used by the various client connections
         */
        this.activeModulePaths = [];
        // Mapping from <absolute file path> => "<namespace>/<componentname>/component.js"
        this.fileToModuleMap = Object.create(null);
        // Mapping from "<namespace>/<componentname>/component.js" => <absolute file path>
        this.moduleToFileMap = Object.create(null);
        this.workspaceScanner = getWorkspaceScanner(workspace, paths);
        this.logger = logger;
        this.moduleMap = this.workspaceScanner.getModulesMap();
        if (this.moduleMap.length) {
            this.logger.log(LogLevel.debug, `Found ${this.moduleMap.length} LWC components in the current workspace.`);
        }
        else {
            this.logger.log(LogLevel.debug, `Found no LWC components in the current workspace, check your settings in lwc.config.json.`);
        }
        this.moduleMap.forEach(({ moduleParts }) => {
            Object.assign(this.moduleToFileMap, moduleParts);
            for (const [modulePath, filePath] of Object.entries(moduleParts)) {
                this.fileToModuleMap[filePath] = modulePath;
            }
        });
    }
    getModuleByFile(path) {
        return this.fileToModuleMap[path];
    }
    getFileByModulePath(modulePath) {
        return this.moduleToFileMap[modulePath];
    }
    // Register the active paths that the client is interested in
    registerActivePaths(activeModules) {
        activeModules.forEach((mod) => {
            const { data: { modulePath }, } = mod;
            if (modulePath.trim()) {
                this.activeModulePaths.push(modulePath);
            }
        });
    }
}
//# sourceMappingURL=index.js.map